@@ -1,4 +1,4 @@
-from infi.instruct import ULInt64, ULInt32, ULInt16, ULInt8, Field, FixedSizeArray, FixedSizeString
+from infi.instruct import SLInt64, ULInt64, ULInt32, ULInt16, ULInt8, Field, FixedSizeArray, FixedSizeString
 from infi.instruct import Struct
 
 def is_64bit():
@@ -16,7 +16,7 @@ ULONG64 = ULInt64
 WCHAR = ULInt16
 
 class LARGE_INTEGER(Struct):
-    _fields_ = [ULInt64("QuadPart"), ] if is_64bit() else [DWORD("LowPart"), DWORD("HighPart")]
+    _fields_ = [SLInt64("QuadPart"), ] if is_64bit() else [DWORD("LowPart"), DWORD("HighPart")]
 
 class GUID(Struct):
     _fields_ = [DWORD("Data1"), WORD("Data2"), WORD("Data3"), FixedSizeArray("Data4", 8, BYTE)]
